% Script MSD_locerr

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press
%
% Please refer to the online manual for detailed usage instructions

clear;
close all;

% Input dialog box for stresses in xy coordinate system
prompt={'t_p picking uncertainty (ms)','t_s picking uncertainty (ms)','Azimuth uncertainty (deg)','Velocity model file','Source points file','Vp (m/s)','Vs (m/s)'};
name='MSD_parameters';

numlines=1;
defaultanswer={'2','4','15','vmodel.txt','sourcepts.txt','4000','2100'};
options.Resize='on';
options.WindowStyle='normal';
options.Interpreter='tex';
answer=inputdlg(prompt,name,numlines,defaultanswer,options);

tperr = str2double(answer(1))/1000;
tserr = str2double(answer(2))/1000;
therr = str2double(answer(3));
velfile = answer{4};
spfile = answer{5};
Vp = str2double(answer(6));
Vs = str2double(answer(7));

Ne = 50;


sensorfile = uigetfile('*.txt','Select sensor geometry file');

fid = fopen(sensorfile);

s = fscanf(fid,'%f');

fclose(fid);

rx = s(1:3:length(s));
ry = s(2:3:length(s));
rz = s(3:3:length(s));

params.ntr = length(rx);

fid = fopen(spfile);

s = fscanf(fid,'%f');
fclose(fid);

sx = s(1:3:length(s));
sy = s(2:3:length(s));
sz = s(3:3:length(s));

% Make plot

plot3(rx,ry,rz,'g^','MarkerFaceColor','g');
set(gca,'zdir','reverse');
hold on;
plot3(sx,sy,sz,'mo','MarkerFaceColor','m');

disp('Computing event locations');

for i = 1:length(sx);
    
    % Compute pick times and inclination
    
   
    for j = 1:params.ntr;
        
        sr = sqrt((sx(i)-rx(j))^2+(sy(i)-ry(j))^2+(sz(i)-rz(j))^2);
        tp_pick(j) = sr/Vp;
        ts_pick(j) = sr/Vs;
        pchan(j) = j;
        [thd(j),inc(j),rev] = cart2sph(sx(i)-rx(j),sy(i)-ry(j),sz(i)-rz(j));
        inc(j) = inc(j)*180/pi;
        thd(j) = thd(j)*180/pi;
    end
        
    % Add noise to picks

    for j = 1:Ne
        tp_picke = tp_pick + (2*rand(1,params.ntr)-1)*tperr;
        ts_picke = ts_pick + (2*rand(1,params.ntr)-1)*tperr;
        
        rsph = (ts_picke - tp_picke)*Vp*Vs/(Vp-Vs);
        
        thhat = thd + (2*rand(1,params.ntr)-1)*therr;
        thhat = thhat*pi/180;
        inchat = inc + (2*rand(1,params.ntr)-1)*therr;
        inchat = inchat*pi/180;
        
        for k = 1:params.ntr;
           [xloch(k),yloch(k),zloch(k)] = sph2cart(thhat(k),inchat(k),rsph(k));
           xloch(k) = xloch(k) + rx(k);
           yloch(k) = yloch(k) + ry(k);
           zloch(k) = rz(k) + zloch(k);
        end
        
        xloc(j) = mean(xloch);
        yloc(j) = mean(yloch);
        zloc(j) = mean(zloch);
  
    end
    
    xe(i) = 2*std(xloc - sx(i));
    ye(i) = 2*std(yloc - sy(i));
    ze(i) = 2*std(zloc - sz(i));
    

    locerr(i) = sqrt(xe(i)^2+ye(i)^2+ze(i)^2);
    
    plot3(xloc,yloc,zloc,'k+');

end


        
        
        