% Script MSD_mti

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press
%
% Please refer to the online manual for detailed usage instructions

clear;
close all;

% Input dialog box 
prompt={'Vp (m/s)','Vs (m/s)','rho g/cm^3)','x_m_i_n (m)','x_m_a_x (m)','y_m_i_n (m)','y_m_a_x (m)','z (m)'};
name='MSD_parameters';

numlines=1;
defaultanswer={'4000','2000','2.5','50','550','50','550','1900'};
options.Resize='on';
options.WindowStyle='normal';
options.Interpreter='tex';
answer=inputdlg(prompt,name,numlines,defaultanswer,options);

Vp = str2double(answer(1));
Vs = str2double(answer(2));
rho = str2double(answer(3))*1000;
xmin = str2double(answer(4));
xmax = str2double(answer(5));
ymin = str2double(answer(6));
ymax = str2double(answer(7));
z = str2double(answer(8));

sensorfile = uigetfile('*.txt','Select sensor geometry file');


fid = fopen(sensorfile);

s = fscanf(fid,'%f');

fclose(fid);

rx = s(1:3:length(s));
ry = s(2:3:length(s));
rz = s(3:3:length(s));

xi = [xmin:50:xmax];
yi = [ymin:50:ymax];

for i = 1:length(xi);
    for j = 1:length(yi);
        
        for k = 1:length(rx);
            a = [rx(k)-xi(i),ry(k)-yi(j),rz(k)-z];
            
           if a == 0
               a = 1e-6;
           end
           
           gamp(k,:) = a/norm(a);
           gams(k,:) = a/norm(a);
           up(k,:) = [1,0,0];
           us(k,:) = [0,1,0];
           
        end
        
        C(i,j) = mu_mti_cn(up,us,gamp,gams,Vp,Vs,rho);
    end
end

figure;

pcolor(xi,yi,C);
shading flat;

title('Condition number for MTI');
xlabel('Distance (m)');
ylabel('Distance (m)');

colorbar vert;
hold on;
plot(rx,ry,'k^','MarkerFaceColor','k','MarkerSize',14);
axis tight;
ax = axis;
axis([ax(1)-50,ax(2)+50,ax(3)-50,ax(4)+50]);



        
            

        
        