function [hinoise,lonoise] = USGS_noise_model(f);
%
% Usage: [hinoise,lonoise] = USGS_noise_model(f);
%
% Input: f - desired frequency (Note: models are defined for frequencies <
% 10 Hz)
%
% Outputs: hinoise,lonoise - displacement spectral value in m / Hz 
%

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press

% Based on Peterson, J., 1993. Observations and modelling of background seismic noise. 
% Open-file report 93-322, U. S. Geological Survey, Albuquerque, New Mexico.
%

P = [0.1,0.22,0.32,0.80,3.80,4.60,6.30,7.90,15.4,20,354.8];
A = [-108.73,-150.34,-122.31,-116.85,-108.48,-74.66,0.66,-93.37,73.54,-151.52,-206.66];
B = [-17.23,-80.50,-23.87,32.51,18.08,-32.95,-127.18,-22.42,-162.98,10.01,31.63];

A2 = [-162.36,-166.7,-170,-166.4,-168.6,-159.98,-141.1,-71.36,-97.26,-132.18,-205.27,-37.65,-114.37,-160.58,-187.5,-216.47,-185.0,-168.34,-217.43,-258.28,-346.88];
B2 = [5.64,0,-8.3,28.9,52.48,29.81,0,-99.77,-66.49,-31.57,36.16,-104.33,-47.1,-16.28,0,15.7,0,-7.61,11.9,26.6,48.75];
P2 = [0.1,0.17,0.4,0.8,1.24,2.4,4.3,5,6,10,12,15.6,21.9,31.6,45,70,101,154,328,600,10000];

NHNM = A + B.*log10(P);
NLNM = A2 + B2.*log10(P2);

% convert from acceleration to displacement

NHNMd = NHNM + 20*log10(P.^2/(4*pi^2));
NLNMd = NLNM + 20*log10(P2.^2/(4*pi^2));

% interpolate to desired frequency

hinoise = interp1(P,NHNMd,1./f,'linear','extrap');
lonoise = interp1(P2,NLNMd,1./f,'linear','extrap');

% Convert to units of m / Hz

hinoise = 10.^(hinoise/20);
lonoise = 10.^(lonoise/20);


