function thresh = magthresh(Qs,noise,Mwi);
% Usage: thresh = magthresh(Qs,noise,Mwi);
%
% Calculates magnitude threshold curve for constant Q model with 
% uniform background noise
%
% Mwi is list of moment magnitudes for the calculation
%
% Calculation assumes Vs = 2500, f = 200 Hz, rho = 2500 kg/m3
%
% thresh represents line for 100% probability of detetion

% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press


V = 2500;
r = [1:15000];
f = 200;
omega = 2*pi*f;
rho = 2500;

for i = 1:length(Mwi);
    M0 = 10^(1.5*(Mwi(i)+6));
    A = omega*0.63*M0.*exp(-pi*f*r/(Qs*V))./(4*pi*rho*V^3*r);
    diff = abs(A-noise);
    [dmin,imin] = min(diff);
    thresh(i) = r(imin);
end

for i = 2:length(thresh);
    if thresh(i) <= thresh(i-1);
        thresh(i) = thresh(i-1)+0.1;
    end
end
