function A = mu_gencm(gamp,gams,vp,vs,rho);
% Usage: A = mu_gencm(gamp,gams,vp,vs,rho);
%
% Program to calculate the coefficient matrix for MTI
%
% Input variables:
%
% gamp - 1 x 3 vector of direction cosines for takeoff ray (P)
% gams - 1 x 3 vector of direction cosines for takeoff ray (S)
% vp,vs,rho - parameters of the medium (SI units)
%
%
% Output:
%
% A - matrix of coefficients to be used by MTI
%
% Author: D. Eaton June 11, 2010
%
 
% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press

%

Ap = 1/(4*pi*rho*vp^3);
As = 1/(4*pi*rho*vs^3);

% Initialize output

A = [0,0,0,0,0,0
    0,0,0,0,0,0
    0,0,0,0,0,0
    0,0,0,0,0,0
    0,0,0,0,0,0
    0,0,0,0,0,0];

for i = 1:3;
   for j = 1:3;
       for k = 1:3;
           
           if j == 1 & k == 1
               l = 1;
           end
           if j == 2 & k == 2
               l = 2;
           end          
           if j == 3 & k == 3
               l = 3;
           end
           if j == 1 & k == 2;
               l = 4;
           end
           if j == 2 & k == 1;
               l = 4;
           end
           if j == 1 & k == 3;
               l = 5;
           end
           if j == 3 & k == 1;
               l = 5;
           end
           if j == 2 & k == 3;
               l = 6;
           end
           if j == 3 & k == 2;
               l = 6;
           end

           A(l,i) = A(l,i) + Ap*gamp(i)*gamp(j)*gamp(k);
           
       end
   end
end


for i = 1:3;
    
   for j = 1:3;
       for k = 1:3;
        
           if j == 1 & k == 1
               l = 1;
           end
           if j == 2 & k == 2
               l = 2;
           end          
           if j == 3 & k == 3
               l = 3;
           end
           if j == 1 & k == 2;
               l = 4;
           end
           if j == 2 & k == 1;
               l = 4;
           end
           if j == 1 & k == 3;
               l = 5;
           end
           if j == 3 & k == 1;
               l = 5;
           end
           if j == 2 & k == 3;
               l = 6;
           end
           if j == 3 & k == 2;
               l = 6;
           end
           
           if i == j;
               A(l,i+3) = A(l,i+3) + As*(1.0 - gams(i)*gams(j))*gams(k);
           else
               A(l,i+3) = A(l,i+3) - As*gams(i)*gams(j)*gams(k);
           end
           
       end
   end
end


A = A';
