function C = mu_mti_cn(up,us,gamp,gams,vp,vs,rho);
%
% Usage: [mout,Mout] = mu_mti_cn(up,us,gamp,gams,vp,vs,rho);
%
% Input arguments:
%
% up (n x 3) - P-wave amplitudes for n 3-component receivers (x,y,z),
%         corrected for geometrical spreading and attenuation
% us (n x 3) - S-wave amplitudes for n 3-component receivers (x,y,z),
%         corrected for geometrical spreading and attenuation
% gamp (n x 3) - P-wave direction cosines for take-off ray
% gams (n x 3) - S-wave direction cosines for take-off ray
% vp,vs,rho - parameters of the medium at the source point
%
% Output:
%
% mout (1 x 6) - moment tensor found by least-squares inversion
% Mout (3 x 3) - Moment tensor in array format
%
% Author: D. Eaton June 11, 2010

%
% Copyright 2018, David W. Eaton, University of Calgary, all rights reserved
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER "AS IS" AND ANY EXPRESS OR 
% IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
% MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
% SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
% INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED 
% TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
% BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
% STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
% OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

% This program accompanies the textbook "Passive Seismic Monitoring of
% Induced Seismicity: Fundamental Principles and Application to Energy
% Technologies", Cambridge University Press

[ntr,m] = size(up);


for i = 1:ntr;
    
   A = mu_gencm(gamp(i,:),gams(i,:),vp,vs,rho);
   
   d = [up(i,1)
       up(i,2)
       up(i,3)
       us(i,1)
       us(i,2)
       us(i,3)];
   
   
   if i == 1;
       AA = A;
       dd = d;
   else
       dd = [dd
           d];
       AA = [AA
           A];
   end
end
       
B = AA'*AA;

C = cond(B);


 